Stan Math Library: stan::math::coupled_ode_observer Struct Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
stan::math::coupled_ode_observer Struct Reference

Observer for the coupled states. More...

`#include <coupled_ode_observer.hpp>`

## Public Member Functions
| coupled_ode_observer (std::vector< std::vector< double > > &y_coupled)
| Construct a coupled ODE observer from the specified coupled vector. More...
void | operator() (const std::vector< double > &coupled_state, const double t)
| Callback function for Boost's ODE solver to record values. More...

## Public Attributes
std::vector< std::vector< double > > & | y_coupled_
int | n_

## Detailed Description

Observer for the coupled states.

Holds a reference to an externally defined vector of vectors passed in at construction time.

Definition at line 15 of file coupled_ode_observer.hpp.

## Constructor & Destructor Documentation

stan::math::coupled_ode_observer::coupled_ode_observer | ( | std::vector< std::vector< double > > & | y_coupled | ) |
| inlineexplicit

Construct a coupled ODE observer from the specified coupled vector.

Parameters

  y_coupled | reference to a vector of vector of doubles.

Definition at line 25 of file coupled_ode_observer.hpp.

## Member Function Documentation

void stan::math::coupled_ode_observer::operator() | ( | const std::vector< double > & | coupled_state,
|  | const double | t
| ) |  |
| inline

Callback function for Boost's ODE solver to record values.

Parameters

  coupled_state | solution at the specified time.
  t | time of solution.

Definition at line 36 of file coupled_ode_observer.hpp.

## Member Data Documentation

int stan::math::coupled_ode_observer::n_

Definition at line 17 of file coupled_ode_observer.hpp.

std::vector<std::vector<double> >& stan::math::coupled_ode_observer::y_coupled_

Definition at line 16 of file coupled_ode_observer.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/arr/functor/coupled_ode_observer.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.